"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
var ts_express_decorators_1 = require("ts-express-decorators");
var ts_log_debug_1 = require("ts-log-debug");
var Path = require("path");
var _error_1 = require("./middlewares/_error");
var agenda_1 = require("./services/agenda");
var config_1 = require("./services/config");
var rootDir = Path.resolve(__dirname);
/**
 * 服务的启动文件
 */
var Server = Server_1 = (function (_super) {
    __extends(Server, _super);
    /**
     * 构造
     * 覆盖基类的信息
     * 挂载controller
     */
    function Server() {
        var _this = _super.call(this) || this;
        // this.scan(`${rootDir}/services/**/**.js`);
        // this.scan(`${rootDir}/constrollers/**/**.js`);
        // this.scan(`${rootDir}/middlewares/**/**.js`);
        _this.mount('/api', rootDir + "/controllers/**/**.js");
        return _this;
    }
    /**
     * 设置自定义中间件
     * @returns {void | Promise<any>}
     */
    Server.prototype.$onMountingMiddlewares = function () {
        var morgan = require('morgan'), cookieParser = require('cookie-parser'), bodyParser = require('body-parser'), compress = require('compression'), methodOverride = require('method-override'), multer = require('multer');
        this
            .use(morgan('dev'))
            .use(ts_express_decorators_1.GlobalAcceptMimesMiddleware)
            .use(cookieParser())
            .use(compress({}))
            .use(methodOverride())
            .use(bodyParser.json())
            .use(bodyParser.urlencoded({
            extended: true
        }))
            .use(multer().single());
        // return this;
    };
    /**
     * lifecircle onReady
     */
    Server.prototype.$onReady = function () {
        ts_log_debug_1.$log.info('Server started...');
    };
    /**
     * lifecircle onServerInitError
     * @param err 错误信息
     */
    Server.prototype.$onServerInitError = function (err) {
        ts_log_debug_1.$log.trace(err);
    };
    /**
     * lifecircle 路由加载完后hook的方法
     * 加载定时任务服务中间件
     * 加载全局错误中间件
     * 手动启动http服务
     */
    Server.prototype.$afterRoutesInit = function (agendaFactory, config) {
        var _a = config.config.baseInfo.http, http = _a === void 0 ? { port: 0 } : _a;
        // 添加定时任务中间件
        this.use("/agendash", agendaFactory.initAgendash());
        // 启用全局错误中间件
        this.use(_error_1.GlobalErrorHandlerMiddleware);
        // 手动启动httpserver
        if (http.port) {
            this.createHttpServer(http.port);
        }
    };
    /**
     * 初始化的lifecircle
     */
    Server.prototype.$onInit = function () {
        ts_log_debug_1.$log.info("oninit");
    };
    /**
     * 初始化服务
     * 打开log的时间
     */
    Server.Initialize = function () {
        var rtn = new Server_1();
        ts_log_debug_1.$log.setPrintDate(true);
        ts_log_debug_1.$log.setRepporting({
            info: true,
            debug: true,
            trace: true,
            error: true,
            warn: true
        });
        return rtn.start();
    };
    return Server;
}(ts_express_decorators_1.ServerLoader));
__decorate([
    ts_express_decorators_1.Inject(),
    __param(0, ts_express_decorators_1.Inject(agenda_1.AgendaService)), __param(1, ts_express_decorators_1.Inject(config_1.ConfigService)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [agenda_1.AgendaService, config_1.ConfigService]),
    __metadata("design:returntype", void 0)
], Server.prototype, "$afterRoutesInit", null);
Server = Server_1 = __decorate([
    ts_express_decorators_1.ServerSettings({
        rootDir: rootDir,
        mount: {},
        httpsPort: undefined,
        componentsScan: [
            rootDir + "/middlewares/**/**.js"
        ],
        acceptMimes: ["application/json"]
    }),
    __metadata("design:paramtypes", [])
], Server);
exports.Server = Server;
Server.Initialize();
var Server_1;
//# sourceMappingURL=index.js.map