import { ConfigService } from './config';
/**
 * 基础信息的工厂服务
 * 提供爬虫节点的基础信息
 *     pid
 *     currentTask
 *     maxTask
 */
export interface IBaseInfoFactory {
    /**
     * 获取基础节点信息
     */
    getInfo: () => {
        pid: number;
        currentTask: number;
        maxTask: number;
    };
    /**
     * 获取代理节点的基础信息
     */
    getProxyInfo: () => {};
    /**
     * 最大的任务数量
     */
    maxTask: number;
    /**
     * 当前的任务数量
     */
    currentTask: number;
}
/**
 * 基础信息服务
 */
export declare class BaseInfoFactory implements IBaseInfoFactory {
    private configFactory;
    private _maxTask;
    private _currentTask;
    /**
     * 设置基础信息
     * 读取配置文件中maxTask字段
     */
    constructor(configFactory: ConfigService);
    /**
     * 设置最大任务数
     */
    maxTask: number;
    /**
     * 设置当前的任务数量
     */
    currentTask: number;
    /**
     * 获取基础信息
     * pid
     * currentTask
     * maxTask
     */
    getInfo(): any;
    /**
     * 获取代理节点的基础信息
     */
    getProxyInfo(): any;
}
