/**
 * 更换代理服务
 * 第一步：关闭nginx
 * 第二步：关闭pptp通道
 * 第三步：创建通道
 * 第四步：添加默认网关并且验证通道创建的地址是否在网关里面
 * 第五步：延时3s，重启nginx
 */
export declare class ProxyService {
    private _pptpChannel;
    /**
     * 关闭nginx
     */
    private closeNginx();
    /**
     * 开启nginx
     */
    private openNginx();
    /**
     * 创建pptp通道
     * @param account
     * @param password
     * @param server
     */
    private pptpsetup(account, password, server);
    /**
     * 设置路由表
     * @param lastIp ip地址
     */
    private setRoute(lastIp);
    /**
     * 重启nginx
     */
    private restartNginx();
    /**
     * 关闭之前创建的通道
     */
    private poff();
    /**
     * 执行更换代理操作
     * 此处nginx作为正向代理服务器来使用
     * 因为通过了vpn拨号，因此当前机器的出口ip地址已被更换成vpn的ip
     * 从而绕过网站的反扒策略
     *
     * 第一步：关闭nginx
     * 第二步：关闭pptp通道
     * 第三步：创建通道
     * 第四步：添加默认网关并且验证通道创建的地址是否在网关里面
     * 第五步：延时3s，重启nginx
     * @param account  代理账户
     * @param password 代理密码
     * @param server   代理服务器
     */
    execute(account: string, password: string, server: string): Promise<any>;
}
