import { ConfigService } from './config';
import { ProxyService } from "./proxy";
import { BaseInfoFactory } from "./baseinfo";
export interface IProxyInfo {
    account: string;
    server: string;
    password: string;
}
/**
 * 基础信息的工厂服务
 * 提供爬虫节点的基础信息
 */
export interface IProxyInfoFactory {
    /**
     * 获取基础节点信息
     */
    getInfo: () => any;
    /**
     * 代理信息
     * account:账号
     * server:服务器
     * password:密码
     */
    proxyInfo: IProxyInfo;
    /**
     * 执行更换代理服务
     * @param proxyService  代理服务
     * @param agendaService 定时任务服务
     */
    initPptpsetupSchedule(proxyService: ProxyService): Promise<any>;
}
/**
 * 基础信息服务
 */
export declare class ProxyInfoFactory implements IProxyInfoFactory {
    private configFactory;
    private baseInfoFactory;
    private _proxyInfo;
    private _running;
    private _errorMsg;
    private _lastUpdateAt;
    /**
     * 设置代理信息
     */
    /**
     * 设置代理信息
     */
    proxyInfo: IProxyInfo;
    /**
     * 设置基础信息
     * 读取配置文件中maxTask字段
     */
    constructor(configFactory: ConfigService, baseInfoFactory: BaseInfoFactory);
    /**
     * 更改代理事件
     * @param proxyService  代理服务
     * @param agendaService 定时任务服务
     */
    initPptpsetupSchedule(proxyService: ProxyService): Promise<void>;
    /**
     * 获取基础信息
     * pid
     * currentTask
     * maxTask
     */
    getInfo(): {
        type: string;
        pid: number;
        callIp: any;
        callPort: number;
        ip: string;
        running: boolean;
        errMsg: string;
        proxyInfo: IProxyInfo;
        lastUpdateAt: number;
    };
}
